# Generated by Django 2.0.9 on 2018-11-19 16:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("cast", "0014_auto_20181119_1616")]

    operations = [
        migrations.AddField(
            model_name="blog",
            name="keywords",
            field=models.CharField(
                blank=True,
                help_text="A comma-demlimitedlist of up to 12 words for iTunes\n            searches. Perhaps include misspellings of the title.",
                max_length=255,
                verbose_name="keywords",
            ),
        )
    ]
