# Generated by Django 2.0.9 on 2018-11-19 17:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("cast", "0016_post_keywords")]

    operations = [
        migrations.AddField(
            model_name="blog",
            name="explicit",
            field=models.PositiveSmallIntegerField(
                choices=[(1, "yes"), (2, "no"), (3, "clean")],
                default=1,
                help_text="``Clean`` will put the clean iTunes graphic by it.",
                verbose_name="explicit",
            ),
        ),
        migrations.AddField(
            model_name="post",
            name="explicit",
            field=models.PositiveSmallIntegerField(
                choices=[(1, "yes"), (2, "no"), (3, "clean")],
                default=1,
                help_text="``Clean`` will put the clean iTunes graphic by it.",
                verbose_name="explicit",
            ),
        ),
    ]
