# Generated by Django 2.1.3 on 2018-11-21 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("cast", "0019_auto_20181120_1024")]

    operations = [
        migrations.AddField(
            model_name="blog",
            name="itunes_categories",
            field=models.CharField(
                blank=True,
                default="",
                help_text="A json dict of itunes categories pointing to lists of subcategories. Taken from this list https://validator.w3.org/feed/docs/error/InvalidItunesCategory.html",
                max_length=512,
                verbose_name="itunes_categories",
            ),
        ),
        migrations.AlterField(
            model_name="blog",
            name="keywords",
            field=models.CharField(
                blank=True,
                default="",
                help_text="A comma-delimitedlist of up to 12 words for iTunes\n            searches. Perhaps include misspellings of the title.",
                max_length=255,
                verbose_name="keywords",
            ),
        ),
        migrations.AlterField(
            model_name="post",
            name="keywords",
            field=models.CharField(
                blank=True,
                default="",
                help_text="A comma-demlimitedlist of up to 12 words for iTunes\n            searches. Perhaps include misspellings of the title.",
                max_length=255,
                verbose_name="keywords",
            ),
        ),
    ]
