# Generated by Django 2.1.7 on 2019-02-26 05:17

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [("cast", "0020_auto_20181121_1446")]

    operations = [
        migrations.AlterField(
            model_name="post",
            name="visible_date",
            field=models.DateTimeField(default=django.utils.timezone.now),
        )
    ]
